"""
Tests for wrapper for GarlandTools Data Endpoint
"""

from . import data


def test_data_is_ok():
    """
    Tests if an data request succeeds
    """
    response = data()
    assert response.ok


def test_data_is_json():
    """
    Tests if an data request returns JSON
    """
    response = data()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Tests for wrapper for GarlandTools Status Endpoint
"""

from . import status, statuses


def test_status_is_ok():
    """
    Tests if an status request succeeds
    """
    response = status(1)
    assert response.ok


def test_status_is_json():
    """
    Tests if an status request returns JSON
    """
    response = status(1)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_statuses_is_ok():
    """
    Tests if an statuses request succeeds
    """
    response = statuses()
    assert response.ok


def test_statuses_is_json():
    """
    Tests if an statuses request returns JSON
    """
    response = statuses()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Wrapper for GarlandTools Leve Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_LEVE_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'leve/{GARLAND_TOOLS_LANGUAGE}/3/'
GARLAND_TOOLS_LEVES_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/leve.json'


def leve(leve_id: int):
    """
    Returns an leve by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_LEVE_ENDPOINT}{leve_id}.json')
    return result


def leves():
    """
    Returns all leves
    """
    result = SESSION.get(GARLAND_TOOLS_LEVES_ENDPOINT)
    return result



"""
Job Enum
"""

from enum import Enum


class Job(str, Enum):
    """
    Job Enum
    """
    # Tanks
    PALADIN = 'PLD'
    WARRIOR = 'WAR'
    DARK_KNIGHT = 'DRK'
    GUN_BREAKER = 'GNB'
    # Healer
    WHITE_MAGE = 'WHM'
    SCHOLAR = 'SCH'
    ASTROLOGIAN = 'AST'
    SAGE = 'SGE'
    # Melee DPS
    MONK = 'MNK'
    DRAGOON = 'DRG'
    NINJA = 'NIN'
    SAMURAI = 'SAM'
    REAPER = 'RPR'
    # Physical Ranged DPS
    BARD = 'BRD'
    MACHINIST = 'MCH'
    DANCER = 'DNC'
    # Magical Ranged DPS
    BLACK_MAGE = 'BLM'
    SUMMONER = 'SMN'
    RED_MAGE = 'RDM'
    BLUE_MAGE = 'BLU'
    # Domain of the Hand
    CARPENTER = 'CRP'
    BLACKSMITH = 'BSM'
    ARMORER = 'ARM'
    GOLDSMITH = 'GSM'
    LEATHERWORKER = 'LTW'
    WEAVER = 'WVR'
    ALCHEMIST = 'ALC'
    CULINARIAN = 'CUL'
    # Domain of the Land
    MINER = 'MIN'
    BOTANIST = 'BTN'
    FISHER = 'FSH'

    def __str__(self):
        """
        Returns the three letter abbreviation of the job
        """
        return self.value

    def get_abbreviation(self):
        """
        Returns the three letter abbreviation of the job
        """
        return self.value



"""
Tests for wrapper for GarlandTools Quest Endpoint
"""

from . import quest, quests


def test_quest_is_ok():
    """
    Tests if an quest request succeeds
    """
    response = quest(65537)
    assert response.ok


def test_quest_is_json():
    """
    Tests if an quest request returns JSON
    """
    response = quest(65537)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_quests_is_ok():
    """
    Tests if an quests request succeeds
    """
    response = quests()
    assert response.ok


def test_quests_is_json():
    """
    Tests if an quests request returns JSON
    """
    response = quests()
    assert response.ok
    print(response.url)

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Wrapper for GarlandTools Mob Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_MOB_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'mob/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_MOBS_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/mob.json'


def mob(mob_id: int):
    """
    Returns an mob by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_MOB_ENDPOINT}{mob_id}.json')
    return result


def mobs():
    """
    Returns all mobs
    """
    result = SESSION.get(GARLAND_TOOLS_MOBS_ENDPOINT)
    return result



"""
Tests for wrapper for GarlandTools Search Endpoint
"""

from . import search


def test_search_is_ok():
    """
    Tests if an search request succeeds
    """
    response = search("Radiant")
    assert response.ok


def test_search_is_json():
    """
    Tests if an search request returns JSON
    """
    response = search("Radiant")
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, list)



"""
Wrapper for GarlandTools Node Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_NODE_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'node/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_NODES_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/node.json'


def node(node_id: int):
    """
    Returns an node by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_NODE_ENDPOINT}{node_id}.json')
    return result


def nodes():
    """
    Returns all nodes
    """
    result = SESSION.get(GARLAND_TOOLS_NODES_ENDPOINT)
    return result



"""
Wrapper for GarlandTools NPC Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_NPC_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'npc/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_NPCS_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/npc.json'


def npc(npc_id: int):
    """
    Returns an npc by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_NPC_ENDPOINT}{npc_id}.json')
    return result


def npcs():
    """
    Returns all npcs
    """
    result = SESSION.get(GARLAND_TOOLS_NPCS_ENDPOINT)
    return result



"""
Tests for wrapper for GarlandTools Instance Endpoint
"""

from . import instance, instances


def test_instance_is_ok():
    """
    Tests if an instance request succeeds
    """
    response = instance(1)
    assert response.ok


def test_instance_is_json():
    """
    Tests if an instance request returns JSON
    """
    response = instance(1)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_instances_is_ok():
    """
    Tests if an instances request succeeds
    """
    response = instances()
    assert response.ok


def test_instances_is_json():
    """
    Tests if an instances request returns JSON
    """
    response = instances()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Tests for wrapper for GarlandTools Job Enum
"""

from . import Job


def test_paladin_matches_abbreviation():
    """
    Tests if the Paladin job matches the abbreviation
    """
    assert Job.PALADIN == 'PLD'


def test_warrior_matches_abbreviation():
    """
    Tests if the Warrior job matches the abbreviation
    """
    assert Job.WARRIOR == 'WAR'


def test_dark_knight_matches_abbreviation():
    """
    Tests if the Dark Knight job matches the abbreviation
    """
    assert Job.DARK_KNIGHT == 'DRK'


def test_gun_breaker_matches_abbreviation():
    """
    Tests if the Gun Breaker job matches the abbreviation
    """
    assert Job.GUN_BREAKER == 'GNB'


def test_white_mage_matches_abbreviation():
    """
    Tests if the White Mage job matches the abbreviation
    """
    assert Job.WHITE_MAGE == 'WHM'


def test_scholar_matches_abbreviation():
    """
    Tests if the Scholar job matches the abbreviation
    """
    assert Job.SCHOLAR == 'SCH'


def test_astrologian_matches_abbreviation():
    """
    Tests if the Astrologian job matches the abbreviation
    """
    assert Job.ASTROLOGIAN == 'AST'


def test_sage_matches_abbreviation():
    """
    Tests if the Sage job matches the abbreviation
    """
    assert Job.SAGE == 'SGE'


def test_monk_matches_abbreviation():
    """
    Tests if the Monk job matches the abbreviation
    """
    assert Job.MONK == 'MNK'


def test_dragoon_matches_abbreviation():
    """
    Tests if the Dragoon job matches the abbreviation
    """
    assert Job.DRAGOON == 'DRG'


def test_ninja_matches_abbreviation():
    """
    Tests if the Ninja job matches the abbreviation
    """
    assert Job.NINJA == 'NIN'


def test_samurai_matches_abbreviation():
    """
    Tests if the Samurai job matches the abbreviation
    """
    assert Job.SAMURAI == 'SAM'


def test_reaper_matches_abbreviation():
    """
    Tests if the Reaper job matches the abbreviation
    """
    assert Job.REAPER == 'RPR'


def test_bard_matches_abbreviation():
    """
    Tests if the Bard job matches the abbreviation
    """
    assert Job.BARD == 'BRD'


def test_machinist_matches_abbreviation():
    """
    Tests if the Machinist job matches the abbreviation
    """
    assert Job.MACHINIST == 'MCH'


def test_dancer_matches_abbreviation():
    """
    Tests if the Dancer job matches the abbreviation
    """
    assert Job.DANCER == 'DNC'


def test_black_mage_matches_abbreviation():
    """
    Tests if the Black Mage job matches the abbreviation
    """
    assert Job.BLACK_MAGE == 'BLM'


def test_summoner_matches_abbreviation():
    """
    Tests if the Summoner job matches the abbreviation
    """
    assert Job.SUMMONER == 'SMN'


def test_red_mage_matches_abbreviation():
    """
    Tests if the Red Mage job matches the abbreviation
    """
    assert Job.RED_MAGE == 'RDM'


def test_blue_mage_matches_abbreviation():
    """
    Tests if the Blue Mage job matches the abbreviation
    """
    assert Job.BLUE_MAGE == 'BLU'


def test_carpenter_matches_abbreviation():
    """
    Tests if the Carpenter job matches the abbreviation
    """
    assert Job.CARPENTER == 'CRP'


def test_blacksmith_matches_abbreviation():
    """
    Tests if the Blacksmith job matches the abbreviation
    """
    assert Job.BLACKSMITH == 'BSM'


def test_armorer_matches_abbreviation():
    """
    Tests if the Armorer job matches the abbreviation
    """
    assert Job.ARMORER == 'ARM'


def test_goldsmith_matches_abbreviation():
    """
    Tests if the Goldsmith job matches the abbreviation
    """
    assert Job.GOLDSMITH == 'GSM'


def test_leatherworker_matches_abbreviation():
    """
    Tests if the Leatherworker job matches the abbreviation
    """
    assert Job.LEATHERWORKER == 'LTW'


def test_weaver_matches_abbreviation():
    """
    Tests if the Weaver job matches the abbreviation
    """
    assert Job.WEAVER == 'WVR'


def test_alchemist_matches_abbreviation():
    """
    Tests if the Alchemist job matches the abbreviation
    """
    assert Job.ALCHEMIST == 'ALC'


def test_culinarian_matches_abbreviation():
    """
    Tests if the Culinarian job matches the abbreviation
    """
    assert Job.CULINARIAN == 'CUL'


def test_miner_matches_abbreviation():
    """
    Tests if the Miner job matches the abbreviation
    """
    assert Job.MINER == 'MIN'


def test_botanist_matches_abbreviation():
    """
    Tests if the Botanist job matches the abbreviation
    """
    assert Job.BOTANIST == 'BTN'


def test_fisher_matches_abbreviation():
    """
    Tests if the Fisher job matches the abbreviation
    """
    assert Job.FISHER == 'FSH'



"""
Wrapper for GarlandTools Data Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_DATA_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'core/{GARLAND_TOOLS_LANGUAGE}/3/data.json'


def data():
    """
    Returns all core data
    """
    result = SESSION.get(GARLAND_TOOLS_DATA_ENDPOINT)
    return result



"""
GarlandTools Python Module
"""

from .globals import *
from .job import *
from .endpoint_item import *
from .endpoint_achievement import *
from .endpoint_data import *
from .endpoint_endgame_gear import *
from .endpoint_fate import *
from .endpoint_fishing import *
from .endpoint_icon import *
from .endpoint_instance import *
from .endpoint_leve import *
from .endpoint_leveling_gear import *
from .endpoint_map import *
from .endpoint_mob import *
from .endpoint_node import *
from .endpoint_npc import *
from .endpoint_search import *
from .endpoint_status import *
from .endpoint_quest import *


__version__ = "0.1.0"
__author__ = 'Lukas Weber'
__credits__ = 'GarlandTools'



"""
Wrapper for GarlandTools Icon Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, SESSION

GARLAND_TOOLS_ICON_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}files/icons/'


def icon(icon_type: str, icon_id: int):
    """
    Returns a specific icon by icon_type and icon_id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_ICON_ENDPOINT}{icon_type}/{icon_id}.png')
    return result



"""
Wrapper for GarlandTools Fate Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_FATE_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'fate/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_FATES_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/fate.json'


def fate(fate_id: int):
    """
    Returns an fate by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_FATE_ENDPOINT}{fate_id}.json')
    return result


def fates():
    """
    Returns all fates
    """
    result = SESSION.get(GARLAND_TOOLS_FATES_ENDPOINT)
    return result



"""
Tests for Author being correctly set in __init__.py
"""

from garlandtools import __author__


def test_author():
    """
    Tests for Author being correctly set in __init__.py
    """
    assert __author__ == "Lukas Weber"



"""
Wrapper for GarlandTools Achievement Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_ACHIEVEMENT_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'achievement/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_ACHIEVEMENTS_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/achievement.json'


def achievement(achievement_id: int):
    """
    Returns an achievement by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_ACHIEVEMENT_ENDPOINT}{achievement_id}.json')
    return result


def achievements():
    """
    Returns all achievements
    """
    result = SESSION.get(GARLAND_TOOLS_ACHIEVEMENTS_ENDPOINT)
    return result



"""
Tests for wrapper for GarlandTools NPC Endpoint
"""

from . import npc, npcs


def test_npc_is_ok():
    """
    Tests if an npc request succeeds
    """
    response = npc(1000063)
    assert response.ok


def test_npc_is_json():
    """
    Tests if an npc request returns JSON
    """
    response = npc(1000063)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_npcs_is_ok():
    """
    Tests if an npcs request succeeds
    """
    response = npcs()
    assert response.ok


def test_npcs_is_json():
    """
    Tests if an npcs request returns JSON
    """
    response = npcs()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Tests for wrapper for GarlandTools Fate Endpoint
"""

from . import fate, fates


def test_fate_is_ok():
    """
    Tests if an fate request succeeds
    """
    response = fate(
        1631)   # Don't even ask me why it's starting at that number.
    # This is one of the first Lv1 FATEs.
    assert response.ok


def test_fate_is_json():
    """
    Tests if an fate request returns JSON
    """
    response = fate(
        1631)   # Don't even ask me why it's starting at that number.
    # This is one of the first Lv1 FATEs.
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_fates_is_ok():
    """
    Tests if an fates request succeeds
    """
    response = fates()
    assert response.ok


def test_fates_is_json():
    """
    Tests if an fates request returns JSON
    """
    response = fates()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Tests for wrapper for GarlandTools Map Endpoint
"""

from . import map_zone


def test_map_zone_is_ok():
    """
    Tests if an map request succeeds
    """
    response = map_zone('La Noscea/Lower La Noscea')
    assert response.ok



"""
Tests for wrapper for GarlandTools Leve Endpoint
"""

from . import leve, leves


def test_leve_is_ok():
    """
    Tests if an leve request succeeds
    """
    response = leve(21)
    assert response.ok


def test_leve_is_json():
    """
    Tests if an leve request returns JSON
    """
    response = leve(21)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_leves_is_ok():
    """
    Tests if an leves request succeeds
    """
    response = leves()
    assert response.ok


def test_leves_is_json():
    """
    Tests if an leves request returns JSON
    """
    response = leves()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Wrapper for GarlandTools Item Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_ITEM_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/item/{GARLAND_TOOLS_LANGUAGE}/3/'


def item(item_id: int):
    """
    Returns a item by id

    Format: PNG
    """
    result = SESSION.get(f'{GARLAND_TOOLS_ITEM_ENDPOINT}{item_id}.json')
    return result



"""
Tests for wrapper for GarlandTools Fishing Endpoint
"""

from . import fishing


def test_fishing_is_ok():
    """
    Tests if an fishing request succeeds
    """
    response = fishing()
    assert response.ok


def test_fishing_is_json():
    """
    Tests if an fishing request returns JSON
    """
    response = fishing()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Tests for wrapper for GarlandTools Icon Endpoint
"""

from . import icon


def test_icon_is_ok():
    """
    Tests if an icon request succeeds
    """
    response = icon('item', 22614)
    assert response.ok



"""
Wrapper for GarlandTools Status Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_STATUS_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'Status/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_STATUSES_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/status.json'


def status(status_id: int):
    """
    Returns a status by id
    """
    result = SESSION.get(f'{GARLAND_TOOLS_STATUS_ENDPOINT}{status_id}.json')
    return result


def statuses():
    """
    Returns all statuses
    """
    result = SESSION.get(f'{GARLAND_TOOLS_STATUSES_ENDPOINT}')
    return result



"""
Wrapper for GarlandTools Search Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_SEARCH_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}api/search.php'


def search(query: str):
    """
    Submits a search query and returns the results
    """
    result = SESSION.get(f'{GARLAND_TOOLS_SEARCH_ENDPOINT}'
                         + f'?text={query}&lang={GARLAND_TOOLS_LANGUAGE}')
    return result



"""
Tests for Version being correctly set in __init__.py
"""

from garlandtools import __version__


def test_version():
    """
    Tests for Version being correctly set in __init__.py
    """
    assert __version__ == "0.1.0"



"""
Tests for wrapper for GarlandTools Node Endpoint
"""

from . import node, nodes


def test_node_is_ok():
    """
    Tests if an node request succeeds
    """
    response = node(153)
    assert response.ok


def test_node_is_json():
    """
    Tests if an node request returns JSON
    """
    response = node(153)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_nodes_is_ok():
    """
    Tests if an nodes request succeeds
    """
    response = nodes()
    assert response.ok


def test_nodes_is_json():
    """
    Tests if an nodes request returns JSON
    """
    response = nodes()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Tests for wrapper for GarlandTools Mob Endpoint
"""

from . import mob, mobs


def test_mob_is_ok():
    """
    Tests if an mob request succeeds
    """
    response = mob(20000000002)
    assert response.ok


def test_mob_is_json():
    """
    Tests if an mob request returns JSON
    """
    response = mob(20000000002)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_mobs_is_ok():
    """
    Tests if an mobs request succeeds
    """
    response = mobs()
    assert response.ok


def test_mobs_is_json():
    """
    Tests if an mobs request returns JSON
    """
    response = mobs()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Wrapper for GarlandTools Quest Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_QUEST_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'quest/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_QUESTS_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/quest.json'


def quest(quest_id: int):
    """
    Returns an quest by id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_QUEST_ENDPOINT}{quest_id}.json')
    return result


def quests():
    """
    Returns all quests
    """
    result = SESSION.get(GARLAND_TOOLS_QUESTS_ENDPOINT)
    return result



"""
Wrapper for GarlandTools Fishing Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_FISHING_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/fishing.json'


def fishing():
    """
    Returns all fishing data
    """
    result = SESSION.get(GARLAND_TOOLS_FISHING_ENDPOINT)
    return result



"""
Tests for Credits being correctly set in __init__.py
"""

from garlandtools import __credits__


def test_credits():
    """
    Tests for Credits being correctly set in __init__.py
    """
    assert __credits__ == "GarlandTools"



"""
Wrapper for GarlandTools Leveling Gear Endpoint
"""

from .job import Job
from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_LEVELLING_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'equip/{GARLAND_TOOLS_LANGUAGE}/2/leveling-'


def leveling_gear(job: Job):
    """
    Returns levelling gear based on job
    """
    result = SESSION.get(f'{GARLAND_TOOLS_LEVELLING_ENDPOINT}{job}.json')
    return result



"""
Wrapper for GarlandTools Map Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, SESSION

GARLAND_TOOLS_MAP_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}files/maps/'


def map_zone(zone: str):
    """
    Returns a specific map by the zone.
    Some zones require the parent zone as well.
    E.g.: La Noscea/Lower La Noscea

    Format: PNG
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_MAP_ENDPOINT}{zone}.png')
    return result



from setuptools import setup

setup(
    name='garlandtools',
    version='1.0.1',
    description='Python PIP module for GarlandTools',
    url='https://github.com/Sakul6499/GarlandTools-PIP',
    author='Lukas Weber',
    author_email='me@sakul6499.de',
    license='MIT License',
    packages=['garlandtools'],
    long_description="Unofficial Python wrapper for [GarlandTools](https://garlandtools.org/) API. Check the [GitHub Repository](https://github.com/Sakul6499/GarlandTools-PIP) for more information.",
    long_description_content_type='text/markdown',
    install_requires=['mpi4py>=2.0',
                      'requests-cache>=0.9'],
    classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Science/Research',
        'License :: OSI Approved :: MIT License',
        'Operating System :: POSIX :: Linux',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.10',
    ],
)



"""
Tests for wrapper for GarlandTools EndGame Gear Endpoint
"""

from . import endgame_gear, Job


def test_endgame_gear_is_ok():
    """
    Tests if an Endgame Gear request succeeds
    """
    response = endgame_gear(Job.WHITE_MAGE)
    assert response.ok


def test_endgame_gear_is_json():
    """
    Tests if an endgame_gear request returns JSON
    """
    response = endgame_gear(Job.WHITE_MAGE)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_endgame_gear_all_jobs():
    """
    Tests if an endgame_gear request returns JSON for all jobs
    """
    for job in Job:
        response = endgame_gear(job)
        assert response.ok

        response_json = response.json()
        assert isinstance(response_json, dict)



"""
Globals
"""

import requests_cache

GARLAND_TOOLS_ENDPOINT = 'https://www.garlandtools.org/'
GARLAND_TOOLS_LANGUAGE = 'en'

SESSION = requests_cache.CachedSession(
    'garlandtools_cache', backend='sqlite', expire_after=3600)



"""
Wrapper for GarlandTools Endgame Gear Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION
from .job import Job

GARLAND_TOOLS_DATA_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'equip/{GARLAND_TOOLS_LANGUAGE}/2/end-'


def endgame_gear(job: Job):
    """
    Returns recommended endgame gear per job
    Use the common three letter abbreviation of the job.
    E.g.: White Mage => WHM; Warrior => WAR; Ninja => NIN
    """
    result = SESSION.get(f'{GARLAND_TOOLS_DATA_ENDPOINT}{job}.json')
    return result



"""
Tests for wrapper for GarlandTools Achievement Endpoint
"""

from . import achievement, achievements


def test_achievement_is_ok():
    """
    Tests if an achievement request succeeds
    """
    response = achievement(1)
    assert response.ok


def test_achievement_is_json():
    """
    Tests if an achievement request returns JSON
    """
    response = achievement(1)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)


def test_achievements_is_ok():
    """
    Tests if an achievements request succeeds
    """
    response = achievements()
    assert response.ok


def test_achievements_is_json():
    """
    Tests if an achievements request returns JSON
    """
    response = achievements()
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)



"""
Wrapper for GarlandTools Instance Endpoint
"""

from .globals import GARLAND_TOOLS_ENDPOINT, GARLAND_TOOLS_LANGUAGE, SESSION

GARLAND_TOOLS_INSTANCE_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'instance/{GARLAND_TOOLS_LANGUAGE}/2/'
GARLAND_TOOLS_INSTANCES_ENDPOINT = f'{GARLAND_TOOLS_ENDPOINT}db/doc/' \
    + f'browse/{GARLAND_TOOLS_LANGUAGE}/2/instance.json'


def instance(instance_id: int):
    """
    Returns an instance by instance_id
    """
    result = SESSION.get(
        f'{GARLAND_TOOLS_INSTANCE_ENDPOINT}{instance_id}.json')
    return result


def instances():
    """
    Returns all instances
    """
    result = SESSION.get(GARLAND_TOOLS_INSTANCES_ENDPOINT)
    return result



"""
Tests for wrapper for GarlandTools Item Endpoint
"""

from . import item


def test_item_is_ok():
    """
    Tests if an item request succeeds
    """
    response = item(2)
    assert response.ok


def test_item_is_json():
    """
    Tests if an item request returns JSON
    """
    response = item(2)
    assert response.ok

    response_json = response.json()
    assert isinstance(response_json, dict)
